@@ -5,7 +5,7 @@
  * Copyright 2001 James Aylett
  * Copyright 2001,2002 Ananova Ltd
  * Copyright 2002 Intercede 1749 Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2013,2014,2015,2016,2017,2018,2019,2020 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2010,2011,2013,2014,2015,2016,2017,2018,2019,2020,2021 Olly Betts
  * Copyright 2008 Thomas Viehmann
  *
  * This program is free software; you can redistribute it and/or
@@ -107,8 +107,10 @@ vector<SubDB> subdbs;
 static bool query_parsed = false;
 static bool done_query = false;
 static Xapian::docid last = 0;
+static Xapian::docid topdoc = 0;
 
 static Xapian::MSet mset;
+static Xapian::RSet rset;
 
 static map<Xapian::docid, bool> ticked;
 
@@ -255,6 +257,10 @@ read_qp_flags(const string & opt_pfx, unsigned f)
 	const char * s = i->first.c_str() + opt_pfx.size();
 	switch (s[0]) {
 	    case 'a':
+                // Note that the ``Xapian::QueryParser::FLAG_ACCUMULATE`` flag
+                // is or-ed in below because it's needed for ``$stoplist`` and
+                // ``$unstem`` to work correctly, and so is deliberately not
+                // available to specify here.
 		if (strcmp(s, "auto_multiword_synonyms") == 0) {
 		    mask = Xapian::QueryParser::FLAG_AUTO_MULTIWORD_SYNONYMS;
 		    break;
@@ -292,6 +298,12 @@ read_qp_flags(const string & opt_pfx, unsigned f)
 		    break;
 		}
 		break;
+	    case 'n':
+		if (strcmp(s, "no_positions") == 0) {
+		    mask = Xapian::QueryParser::FLAG_NO_POSITIONS;
+		    break;
+		}
+		break;
 	    case 'p':
 		if (strcmp(s, "partial") == 0) {
 		    mask = Xapian::QueryParser::FLAG_PARTIAL;
@@ -920,6 +932,7 @@ CMD_add,
 CMD_addfilter,
 CMD_allterms,
 CMD_and,
+CMD_base64,
 CMD_cgi,
 CMD_cgilist,
 CMD_cgiparams,
@@ -1063,6 +1076,7 @@ T(add,		   0, N, N, 0), // add a list of numbers
 T(addfilter,	   1, 2, N, 0), // add filter term
 T(allterms,	   0, 1, N, 0), // list of all terms matching document
 T(and,		   1, N, 0, 0), // logical shortcutting and of a list of values
+T(base64,	   1, 1, N, 0), // base64 encode
 T(cgi,		   1, 1, N, 0), // return cgi parameter value
 T(cgilist,	   1, 1, N, 0), // return list of values for cgi parameter
 T(cgiparams,	   0, 0, N, 0), // return list of cgi parameter names
@@ -1391,6 +1405,44 @@ eval(const string& fmt, vector<string>& param)
 		}
 		break;
 	    }
+	    case CMD_base64: {
+		const static char encode[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdef"
+					     "ghijklmnopqrstuvwxyz0123456789+/";
+		const char pad = '=';
+		const string& input = args[0];
+		value.reserve((input.size() + 2) / 3 * 4);
+		auto it = input.begin();
+		auto n = input.size() / 3;
+		while (n--) {
+		    uint32_t v = uint8_t(*it++);
+		    v = (v << 8) | uint8_t(*it++);
+		    v = (v << 8) | uint8_t(*it++);
+		    value += encode[v >> 18];
+		    value += encode[(v >> 12) & 63];
+		    value += encode[(v >> 6) & 63];
+		    value += encode[v & 63];
+		}
+		switch (input.size() % 3) {
+		    case 2: {
+			uint32_t v = uint8_t(*it++);
+			v = (v << 8) | uint8_t(*it++);
+			value += encode[v >> 10];
+			value += encode[(v >> 4) & 63];
+			value += encode[(v << 2) & 63];
+			value += pad;
+			break;
+		    }
+		    case 1: {
+			uint32_t v = uint8_t(*it++);
+			value += encode[v >> 2];
+			value += encode[(v << 4) & 63];
+			value += pad;
+			value += pad;
+			break;
+		    }
+		}
+		break;
+	    }
 	    case CMD_cgi: {
 		auto i = cgi_params.find(args[0]);
 		if (i != cgi_params.end()) value = i->second;
